@@ -1,3 +1,7 @@
+.tmp.f <- function(){
+  library(RUnit)
+}
+
 .setUp <- function() {
 	#library(MASS)
 	.setUpDf <- within( list(),{
@@ -32,6 +36,13 @@ test.plogitnorm <- function(){
 	#lines( pnorm( logit(x)) ~ logit(x) )
 }
 
+test.dlogitnorm <- function(){
+  q <- c(-1,0,0.5,1,2)
+  ans <- suppressWarnings(dlogitnorm(q))
+  checkEquals(c(0,0,1.595769,0,0), ans, tolerance = 1e-7)
+}
+
+
 test.twCoefLogitnorm <- function(){
 	theta <- twCoefLogitnorm(0.7,0.9,perc = 0.999)
 	px <- plogitnorm(x,mu = theta[1],sigma = theta[2])	#percentiles function
